==> virtual-additions-4.0.0%2B1.21.9-sources.jar: com/github/suninvr/virtualadditions/block/SpectralFireBlock.java <==
package com.github.suninvr.virtualadditions.block;

import com.github.suninvr.virtualadditions.registry.VABlocks;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_10225;
import net.minecraft.class_10774;
import net.minecraft.class_10776;
import net.minecraft.class_1297;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_4538;
import net.minecraft.class_4770;
import net.minecraft.class_4970;
import net.minecraft.class_5819;

public class SpectralFireBlock extends class_4770 {
    public static final MapCodec<SpectralFireBlock> CODEC = method_54094(SpectralFireBlock::new);

    public SpectralFireBlock(class_4970.class_2251 settings) {
        super(settings, 0.0F);
    }

    @Override
    protected class_2680 method_9559(class_2680 state, class_4538 world, class_10225 tickView, class_2338 pos, class_2350 direction, class_2338 neighborPos, class_2680 neighborState, class_5819 random) {
        return this.method_9558(state, world, pos) ? this.method_9564() : class_2246.field_10124.method_9564();
    }

    @Override
    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        return world.method_8320(pos.method_10074()).method_27852(VABlocks.SPECTRAL_SAND);
    }

    @Override
    protected void method_9548(class_2680 state, class_1937 world, class_2338 pos, class_1297 entity, class_10774 handler) {
        handler.method_67638(class_10776.field_56642);
    }

    @Override
    protected MapCodec<? extends class_4770> method_53969() {
        return field_46280;
    }

    @Override
    protected boolean method_10195(class_2680 state) {
        return false;
    }
}

==> virtual-additions-4.0.1%2B1.21.10-sources.jar: com/github/suninvr/virtualadditions/block/SpectralFireBlock.java <==
package com.github.suninvr.virtualadditions.block;

import com.github.suninvr.virtualadditions.registry.VABlocks;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_10225;
import net.minecraft.class_10774;
import net.minecraft.class_10776;
import net.minecraft.class_1297;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_4538;
import net.minecraft.class_4770;
import net.minecraft.class_4970;
import net.minecraft.class_5819;

public class SpectralFireBlock extends class_4770 {
    public static final MapCodec<SpectralFireBlock> CODEC = method_54094(SpectralFireBlock::new);

    public SpectralFireBlock(class_4970.class_2251 settings) {
        super(settings, 0.0F);
    }

    @Override
    protected class_2680 method_9559(class_2680 state, class_4538 world, class_10225 tickView, class_2338 pos, class_2350 direction, class_2338 neighborPos, class_2680 neighborState, class_5819 random) {
        return this.method_9558(state, world, pos) ? this.method_9564() : class_2246.field_10124.method_9564();
    }

    @Override
    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        return world.method_8320(pos.method_10074()).method_27852(VABlocks.SPECTRAL_SAND);
    }

    @Override
    protected void method_9548(class_2680 state, class_1937 world, class_2338 pos, class_1297 entity, class_10774 handler, boolean bl) {
        handler.method_67638(class_10776.field_56642);
    }

    @Override
    protected MapCodec<? extends class_4770> method_53969() {
        return field_46280;
    }

    @Override
    protected boolean method_10195(class_2680 state) {
        return false;
    }
}
